#!/usr/bin/env python3
# coding=UTF-8

def restart() :
    print("EXAMPLE START: range_anytype")
    for i in [
    "from range_anytype import Range, ProtectedRange",
    "print(Range(9))",
    "print(ProtectedRange(12))",
    "import decimal, fractions",
    "print(Range(9, 32, 0.4))",
    "print(Range(decimal.Decimal(9), decimal.Decimal(32), decimal.Decimal('0.4')))",
    "print(Range(fractions.Fraction(9), fractions.Fraction(32), fractions.Fraction(2, 5)))",
    """\
for i in Range(-fractions.Fraction(256, 24), fractions.Fraction(512, 17), fractions.Fraction(1, 18)) :
    print(i)""",
    "print(tuple(Range(-fractions.Fraction(256, 24), fractions.Fraction(512, 17), fractions.Fraction(1, 18))))"
    ] :
        print(">>> "+"\n... ".join(i.split("\n")))
        exec("global Range, ProtectedRange, decimal, fractions\n"+i)

restart()



#!/usr/bin/env python
# coding=UTF-8

try :
    StopIteration
except NameError :
    class StopIteration(Exception) :
        pass

class Range :
    def __init__(self, *args) :
        if len(args) == 0 :
            raise TypeError("Range expected 1 argument, got 0")
        elif len(args) == 1 : # Range(stop)
            self.start = 0
            self.stop = args[0]
            self.step = 1
            return None
        elif len(args) == 2 : # Range(start, stop)
            self.start = args[0]
            self.stop = args[1]
            self.step = 1
            return None
        elif len(args) == 3 : # Range(start, stop, step)
            self.start = args[0]
            self.stop = args[1]
            self.step = args[2]
            return None
        raise TypeError("Range expected at most 3 arguments, got %d"%len(args))
    
    def __repr__(self) :
        if self.step == 1 :
            return "Range(%s, %s)" % (repr(self.start), repr(self.stop))
        return "Range(%s, %s, %s)" % (repr(self.start), repr(self.stop),
                                      repr(self.step))
    
    def __iter__(self) :
        self.__a = self.start
        return self
    
    try :
        StopIteration
    except NameError :
        StopIteration = StopIteration
    
    def next(self) :
        try :
            if self.__a + self.step > self.__a :
                if self.__a >= self.stop :
                    del self.__a
                    try :
                        StopIteration
                    except NameError :
                        raise self.StopIteration
                    else :
                        raise StopIteration
            elif self.__a + self.step < self.__a :
                if self.__a <= self.stop :
                    del self.__a
                    try :
                        StopIteration
                    except NameError :
                        raise self.StopIteration
                    else :
                        raise StopIteration
            else :
            	raise ValueError("Range() arg 3 must not be zero")
        except AttributeError :
            try :
                StopIteration
            except NameError :
                raise self.StopIteration
            else :
                raise StopIteration
        res = self.__a
        self.__a = self.__a + self.step
        return res
    
    def to_tuple(self) :
        res = ()
        try :
            StopIteration
        except NameError :
            try :
                asatemp = Range(self.start, self.stop, self.step).__iter__()
                while 1 :
                    res = res + (asatemp.next(),)
            except self.StopIteration :
                pass
        else :
            try :
                asatemp = Range(self.start, self.stop, self.step).__iter__()
                while 1 :
                    res = res + (asatemp.next(),)
            except StopIteration :
                pass
        return res
    
    def __bool__(self) :
        return self.to_tuple() != ()
    
    def __len__(self) :
        return len(self.to_tuple())
    
    def __contains__(self, key) :
        return key in self.to_tuple()
    
    def __getitem__(self, key) :
        try :
            if type(key) == type(slice(None)) :
                if key.step != None :
                    if key.step + key.step == key.step :
                        raise ValueError("slice step cannot be zero")
                k = (key.step, 1)[key.step==None]
                labb = self.to_tuple()[key]
                return Range(labb[0], labb[-1]+self.step*k, self.step*k)
        except NameError :
            pass
        try :
            return self.to_tuple()[key]
        except IndexError :
            raise IndexError("Range object index out of range")
    
    def __getslice__(self, x, y) :
        labb = self.to_tuple()[x:y]
        return Range(labb[0], labb[-1]+self.step, self.step)
    
    def __eq__(self, value) :
        try :
            if self.start == value.start and self.stop == value.stop and \
               self.step == value.step :
                return 1
            return self.to_tuple() == tuple(value)
        except (AttributeError, TypeError) :
            return 0
    
    def __ne__(self, value) :
        return not self == value
    
    def __hash__(self) :
        return hash(self.to_tuple())
    
    def count(self, value) :
        return self.to_tuple().count(value)
    
    def index(self, value) :
        try :
            return self.to_tuple().index(value)
        except ValueError :
            raise ValueError("%s is not in Range"%repr(value))
    
class ProtectedRange(Range) :
    def __init__(self, *args) :
        if len(args) == 0 :
            raise TypeError("ProtectedRange expected 1 argument, got 0")
        elif len(args) == 1 :
            self.start = 0
            self.stop = args[0]
            self.step = 1
            return None
        elif len(args) == 2 :
            self.start = args[0]
            self.stop = args[1]
            self.step = 1
            return None
        elif len(args) == 3 :
            self.start = args[0]
            self.stop = args[1]
            self.step = args[2]
            return None
        raise TypeError("ProtectedRange expected at most 3 arguments, got %d"%\
                        len(args))
    
    def __repr__(self) :
        if self.step == 1 :
            return "ProtectedRange(%s, %s)" % (repr(self.start),
                                               repr(self.stop))
        return "ProtectedRange(%s, %s, %s)" % (repr(self.start),
                                               repr(self.stop), repr(self.step))
    
    def __iter__(self) :
        try :
            self.start + self.start - self.start # protect
        except (TypeError, ValueError) :
            raise ValueError("protected range")
        self.__a = self.start
        return self
    
    def next(self) :
        try :
            if self.__a + self.step > self.__a :
                if self.__a >= self.stop :
                    del self.__a
                    try :
                        StopIteration
                    except NameError :
                        raise self.StopIteration
                    else :
                        raise StopIteration
            elif self.__a + self.step < self.__a :
                if self.__a <= self.stop :
                    del self.__a
                    try :
                        StopIteration
                    except NameError :
                        raise self.StopIteration
                    else :
                        raise StopIteration
            else :
            	raise ValueError("ProtectedRange() arg 3 must not be zero")
        except AttributeError :
            try :
                StopIteration
            except NameError :
                raise self.StopIteration
            else :
                raise StopIteration
        res = self.__a
        self.__a = self.__a + self.step
        return res
    
    def to_tuple(self) :
        res = ()
        try :
            StopIteration
        except NameError :
            try :
                asatemp = ProtectedRange(self.start, self.stop,
                                         self.step).__iter__()
                while 1 :
                    res = res + (asatemp.next(),)
            except self.StopIteration :
                pass
        else :
            try :
                asatemp = ProtectedRange(self.start, self.stop,
                                         self.step).__iter__()
                while 1 :
                    res = res + (asatemp.next(),)
            except StopIteration :
                pass
        return res
    
    def __getitem__(self, key) :
        try :
            if type(key) == type(slice(None)) :
                if key.step != None :
                    if key.step + key.step == key.step :
                        raise ValueError("slice step cannot be zero")
                k = (key.step, 1)[key.step==None]
                labb = self.to_tuple()[key]
                return ProtectedRange(labb[0],labb[-1]+self.step*k, self.step*k)
        except NameError :
            pass
        try :
            return self.to_tuple()[key]
        except IndexError :
            raise IndexError("ProtectedRange object index out of range")
    
    def __getslice__(self, x, y) :
        labb = self.to_tuple()[x:y]
        return ProtectedRange(labb[0], labb[-1]+self.step, self.step)
    
    def index(self, value) :
        try :
            return self.to_tuple().index(value)
        except ValueError :
            raise ValueError("%s is not in ProtectedRange"%repr(value))



#!/usr/bin/env python
# coding=UTF-8

"""
range-anytype

Not an accurate Range for float. For best experience, you can use
decimal.Decimal or fractions.Fraction instead of float.
"""

try :
    object
except NameError :
    try :
        from range_anytype.py1compa import * # for Python 2.1 or earlier
    except ImportError :
        from rangeant.py1compa import * # for Python 2.1 or earlier
else :
    try :
        from range_anytype.py22plus import * # for Python 2.2 or newer
    except ImportError :
        from rangeant.py1compa import * # for Python 2.1 or earlier



#!/usr/bin/env python
# coding=UTF-8

"""
range-anytype

Not an accurate Range for float. For best experience, you can use
decimal.Decimal or fractions.Fraction instead of float.
"""

try :
    raw_input
except NameError :
    ispy3 = 1
else :
    ispy3 = 0

class Range(object) :
    """Range(stop) or Range(start, stop[, step])
Like built-in type 'range' or 'xrange', Range is not immutable."""
    
    if ispy3 :
        def __init__(self, *args) :
            """Initialize self.  See help(type(self)) for accurate signature."""
            
            if len(args) == 0 :
                raise TypeError("Range expected 1 argument, got 0")
            elif len(args) == 1 : # Range(stop)
                self.start = 0
                self.stop = args[0]
                self.step = 1
                return None
            elif len(args) == 2 : # Range(start, stop)
                self.start = args[0]
                self.stop = args[1]
                self.step = 1
                return None
            elif len(args) == 3 : # Range(start, stop, step)
                self.start = args[0]
                self.stop = args[1]
                self.step = args[2]
                return None
            raise TypeError("Range expected at most 3 arguments, got %d"%\
                            len(args))
    else :
        def __init__(self, *args) :
            """x.__init__(...) initializes x; see help(type(x)) for signature"""
            
            if len(args) == 0 :
                raise TypeError("Range expected 1 argument, got 0")
            elif len(args) == 1 : # Range(stop)
                self.start = 0
                self.stop = args[0]
                self.step = 1
                return None
            elif len(args) == 2 : # Range(start, stop)
                self.start = args[0]
                self.stop = args[1]
                self.step = 1
                return None
            elif len(args) == 3 : # Range(start, stop, step)
                self.start = args[0]
                self.stop = args[1]
                self.step = args[2]
                return None
            raise TypeError("Range expected at most 3 arguments, got %d"%\
                            len(args))
    
    if ispy3 :
        def __delattr__(self, name) :
            """Execute delattr(self, name)."""
            
            raise AttributeError("%s cannot be deleted" % name)
        
        def __setattr__(self, name, value) :
            """Execute setattr(self, name, value)."""
            
            if name in ("start", "stop", "step") :
                if not hasattr(self, name) :
                    self.__dict__[name] = value
                else :
                    raise AttributeError("can't set attribute")
            else :
                raise AttributeError("can't set attribute")
        
        def __repr__(self) :
            """Return repr(self)."""
            
            if self.step == 1 :
                return "Range(%s, %s)" % (repr(self.start), repr(self.stop))
            return "Range(%s, %s, %s)" % (repr(self.start), repr(self.stop),
                                          repr(self.step))
        
        class Range_iterator(object) :
            def __init__(self, start, stop, step) :
                self.__start = start
                self.__stop = stop
                self.__step = step
            
            def __iter__(self) :
                """Implement iter(self)."""
                
                return self
            
            def __next__(self) :
                """Implement next(self)."""
                
                if hasattr(self, "_Range_iterator__a") :
                    try :
                        if self.__a + self.__step > self.__a :
                            if self.__a >= self.__stop :
                                del self.__a
                                raise StopIteration
                        elif self.__a + self.__step < self.__a :
                            if self.__a <= self.__stop :
                                del self.__a
                                raise StopIteration
                        else :
                            raise ValueError("Range() arg 3 must not be zero")
                    except AttributeError :
                        raise StopIteration
                    res = self.__a
                    self.__a += self.__step
                    return res
                else :
                    self.__a = self.__start
                    self.__next__()
                    return self.__start
            
            def __setattr__(self, name, value) :
                if name in ("_Range_iterator__start", "_Range_iterator__stop",
                            "_Range_iterator__step", "_Range_iterator__a") :
                    if not hasattr(self, name) :
                        self.__dict__[name] = value
                    else :
                        if name != "_Range_iterator__a" :
                            raise AttributeError("can't set attribute")
                        else :
                            self.__dict__[name] = value
                else :
                    raise AttributeError("can't set attribute")
            
            def __delattr__(self, name) :
                if name in ("_Range_iterator__start", "_Range_iterator__stop",
                            "_Range_iterator__step", "_Range_iterator__a") :
                    if name != "_Range_iterator__a" :
                        raise AttributeError("can't delete attribute")
                    else :
                        del self.__dict__[name]
                else :
                    raise AttributeError("can't delete attribute")
        
        def __iter__(self) :
            """Implement iter(self)."""
            
            return type(self).Range_iterator(self.start, self.stop, self.step)
        
        def __bool__(self) :
            """self != 0"""
            
            return tuple(self) != ()
        
        def __len__(self) :
            """Return len(self)."""
            
            res = 0
            for i in type(self)(self.start, self.stop, self.step) :
                res += 1
            return res
        
        def __contains__(self, key) :
            """Return key in self."""
            
            return key in tuple(self)
        
        def __getitem__(self, key) :
            """Return self[key]."""
            
            try :
                if isinstance(key, slice) :
                    if key.step != None :
                        if key.step + key.step == key.step :
                            raise ValueError("slice step cannot be zero")
                    k = (key.step, 1)[key.step==None]
                    labb = tuple(self)[key]
                    return type(self)(labb[0],labb[-1]+self.step*k, self.step*k)
            except NameError :
                pass
            try :
                return tuple(self)[key]
            except IndexError :
                raise IndexError("Range object index out of range")
        
        def __eq__(self, value) :
            """Return self==value."""
            
            try :
                if self.start == value.start and self.stop == value.stop and \
                   self.step == value.step :
                    return True
                return tuple(self) == tuple(value)
            except (AttributeError, TypeError) :
                return False
        
        def __ne__(self, value) :
           """Return self!=value."""
           
           return not self == value
        
        def __hash__(self) :
            """Return hash(self)."""
            
            return hash(tuple(self))
    else :
        def __delattr__(self, name) :
            """Execute delattr(self, name)."""
            
            raise AttributeError("%s cannot be deleted" % name)
        
        def __setattr__(self, name, value) :
            """Execute setattr(self, name, value)."""
            
            if name in ("start", "stop", "step") :
                if not hasattr(self, name) :
                    self.__dict__[name] = value
                else :
                    raise AttributeError("can't set attribute")
            else :
                raise AttributeError("can't set attribute")
        
        def __repr__(self) :
            """x.__repr__() <==> repr(x)"""
            
            if self.step == 1 :
                return "Range(%s, %s)" % (repr(self.start), repr(self.stop))
            return "Range(%s, %s, %s)" % (repr(self.start), repr(self.stop),
                                          repr(self.step))
        
        class Range_iterator(object) :
            def __init__(self, start, stop, step) :
                self.__start = start
                self.__stop = stop
                self.__step = step
            
            def __iter__(self) :
                """x.__iter__() <==> iter(x)"""
                
                return self
            
            def next(self) :
                """x.next() -> the next value, or raise StopIteration"""
                
                if hasattr(self, "_Range_iterator__a") :
                    try :
                        if self.__a + self.__step > self.__a :
                            if self.__a >= self.__stop :
                                del self.__a
                                raise StopIteration
                        elif self.__a + self.__step < self.__a :
                            if self.__a <= self.__stop :
                                del self.__a
                                raise StopIteration
                        else :
                            raise ValueError("Range() arg 3 must not be zero")
                    except AttributeError :
                        raise StopIteration
                    res = self.__a
                    self.__a += self.__step
                    return res
                else :
                    self.__a = self.__start
                    self.next()
                    return self.__start
            
            def __setattr__(self, name, value) :
                if name in ("_Range_iterator__start", "_Range_iterator__stop",
                            "_Range_iterator__step", "_Range_iterator__a") :
                    if not hasattr(self, name) :
                        self.__dict__[name] = value
                    else :
                        if name != "_Range_iterator__a" :
                            raise AttributeError("can't set attribute")
                        else :
                            self.__dict__[name] = value
                else :
                    raise AttributeError("can't set attribute")
            
            def __delattr__(self, name) :
                if name in ("_Range_iterator__start", "_Range_iterator__stop",
                            "_Range_iterator__step", "_Range_iterator__a") :
                    if name != "_Range_iterator__a" :
                        raise AttributeError("can't delete attribute")
                    else :
                        del self.__dict__[name]
                else :
                    raise AttributeError("can't delete attribute")
        
        def __iter__(self) :
            """x.__iter__() <==> iter(x)"""
            
            return type(self).Range_iterator(self.start, self.stop, self.step)
        
        def __bool__(self) :
            """self != 0"""
            
            return tuple(self) != ()
        
        def __len__(self) :
            """x.__len__() <==> len(x)"""
            
            res = 0
            for i in type(self)(self.start, self.stop, self.step) :
                res += 1
            return res
        
        def __contains__(self, key) :
            """x.__contains__(y) <==> y in x"""
            
            return key in tuple(self)
        
        def __getitem__(self, key) :
            """x.__getitem__(y) <==> x[y]"""
            
            try :
                if isinstance(key, slice) :
                    if key.step != None :
                        if key.step + key.step == key.step :
                            raise ValueError("slice step cannot be zero")
                    k = (key.step, 1)[key.step==None]
                    labb = tuple(self)[key]
                    return type(self)(labb[0],labb[-1]+self.step*k, self.step*k)
            except NameError :
                pass
            try :
                return tuple(self)[key]
            except IndexError :
                raise IndexError("Range object index out of range")
        
        def __eq__(self, value) :
            """x.__eq__(y) <==> x==y"""
            
            try :
                if self.start == value.start and self.stop == value.stop and \
                   self.step == value.step :
                    return True
                return tuple(self) == tuple(value)
            except (AttributeError, TypeError) :
                return False
        
        def __ne__(self, value) :
           """x.__ne__(y) <==> x!=y"""
           
           return not self == value
        
        def __hash__(self) :
            """x.__hash__() <==> hash(x)"""
            
            return hash(tuple(self))
    
    def count(self, value) :
        return tuple(self).count(value)
    
    def index(self, value) :
        """Raise ValueError if the value is not present."""
        
        try :
            return tuple(self).index(value)
        except ValueError :
            raise ValueError("%s is not in Range"%repr(value))
    
class ProtectedRange(Range) :
    """ProtectedRange(stop) or peotected_Range(start, stop[, step])
Like built-in type 'range' or 'xrange', ProtectedRange is not immutable."""
    
    if ispy3 :
        def __init__(self, *args) :
            """Initialize self.  See help(type(self)) for accurate signature."""
            
            if len(args) == 0 :
                raise TypeError("ProtectedRange expected 1 argument, got 0")
            elif len(args) == 1 :
                self.start = 0
                self.stop = args[0]
                self.step = 1
                return None
            elif len(args) == 2 :
                self.start = args[0]
                self.stop = args[1]
                self.step = 1
                return None
            elif len(args) == 3 :
                self.start = args[0]
                self.stop = args[1]
                self.step = args[2]
                return None
            raise TypeError("ProtectedRange expected at most 3 arguments, got %\
d"%len(args))
    else :
        def __init__(self, *args) :
            """x.__init__(...) initializes x; see help(type(x)) for signature"""
            
            if len(args) == 0 :
                raise TypeError("ProtectedRange expected 1 argument, got 0")
            elif len(args) == 1 :
                self.start = 0
                self.stop = args[0]
                self.step = 1
                return None
            elif len(args) == 2 :
                self.start = args[0]
                self.stop = args[1]
                self.step = 1
                return None
            elif len(args) == 3 :
                self.start = args[0]
                self.stop = args[1]
                self.step = args[2]
                return None
            raise TypeError("ProtectedRange expected at most 3 arguments, got %\
d"%len(args))
    
    if ispy3 :
        def __delattr__(self, name) :
            """Execute delattr(self, name)."""
            
            raise AttributeError("%s cannot be deleted" % name)
        
        def __setattr__(self, name, value) :
            """Execute setattr(self, name, value)."""
            
            if name in ("start", "stop", "step") :
                if not hasattr(self, name) :
                    self.__dict__[name] = value
                else :
                    raise AttributeError("can't set attribute")
            else :
                raise AttributeError("can't set attribute")
        
        def __repr__(self) :
            """Return repr(self)."""
            
            if self.step == 1 :
                return "ProtectedRange(%s, %s)" % (repr(self.start),
                                                   repr(self.stop))
            return "ProtectedRange(%s, %s, %s)" % (repr(self.start),
                                                   repr(self.stop),
                                                   repr(self.step))
        
        class ProtectedRange_iterator(object) :
            def __init__(self, start, stop, step) :
                self.__start = start
                self.__stop = stop
                self.__step = step
            
            def __iter__(self) :
                """Implement iter(self)."""
                
                return self
            
            def __next__(self) :
                """Implement next(self)."""
                
                if hasattr(self, "_ProtectedRange_iterator__a") :
                    try :
                        if self.__a + self.__step > self.__a :
                            if self.__a >= self.__stop :
                                del self.__a
                                raise StopIteration
                        elif self.__a + self.__step < self.__a :
                            if self.__a <= self.__stop :
                                del self.__a
                                raise StopIteration
                        else :
                            raise ValueError("ProtectedRange() arg 3 must not b\
e zero")
                    except AttributeError :
                        raise StopIteration
                    res = self.__a
                    self.__a += self.__step
                    return res
                else :
                    self.__a = self.__start
                    self.__next__()
                    return self.__start
            
            def __setattr__(self, name, value) :
                if name in ("_ProtectedRange_iterator__start", "_ProtectedRange\
_iterator__stop", "_ProtectedRange_iterator__step", "_ProtectedRange_iterator__\
a") :
                    if not hasattr(self, name) :
                        self.__dict__[name] = value
                    else :
                        if name != "_ProtectedRange_iterator__a" :
                            raise AttributeError("can't set attribute")
                        else :
                            self.__dict__[name] = value
                else :
                    raise AttributeError("can't set attribute")
            
            def __delattr__(self, name) :
                if name in ("_ProtectedRange_iterator__start", "_ProtectedRange\
_iterator__stop", "_ProtectedRange_iterator__step", "_ProtectedRange_iterator__\
a") :
                    if name != "_ProtectedRange_iterator__a" :
                        raise AttributeError("can't delete attribute")
                    else :
                        del self.__dict__[name]
                else :
                    raise AttributeError("can't delete attribute")
        
        def __iter__(self) :
            """Implement iter(self)."""
            
            try :
                self.start + self.start - self.start # protect
            except (TypeError, ValueError, MemoryError) :
                raise ValueError("protected range")
            return type(self).ProtectedRange_iterator(self.start, self.stop,
                                                      self.step)
        
        def __getitem__(self, key) :
            """Return self[key]."""
            
            try :
                if isinstance(key, slice) :
                    if key.step != None :
                        if key.step + key.step == key.step :
                            raise ValueError("slice step cannot be zero")
                    k = (key.step, 1)[key.step==None]
                    labb = tuple(self)[key]
                    return type(self)(labb[0],labb[-1]+self.step*k, self.step*k)
            except NameError :
                pass
            try :
                return tuple(self)[key]
            except IndexError :
                raise IndexError("ProtectedRange object index out of range")
    else :
        def __delattr__(self, name) :
            """Execute delattr(self, name)."""
            
            raise AttributeError("%s cannot be deleted" % name)
        
        def __setattr__(self, name, value) :
            """Execute setattr(self, name, value)."""
            
            if name in ("start", "stop", "step") :
                if not hasattr(self, name) :
                    self.__dict__[name] = value
                else :
                    raise AttributeError("can't set attribute")
            else :
                raise AttributeError("can't set attribute")
        
        class ProtectedRange_iterator(object) :
            def __init__(self, start, stop, step) :
                self.__start = start
                self.__stop = stop
                self.__step = step
            
            def __iter__(self) :
                """x.__iter__() <==> iter(x)"""
                
                return self
            
            def next(self) :
                """x.next() -> the next value, or raise StopIteration"""
                
                if hasattr(self, "_ProtectedRange_iterator__a") :
                    try :
                        if self.__a + self.__step > self.__a :
                            if self.__a >= self.__stop :
                                del self.__a
                                raise StopIteration
                        elif self.__a + self.__step < self.__a :
                            if self.__a <= self.__stop :
                                del self.__a
                                raise StopIteration
                        else :
                            raise ValueError("ProtectedRange() arg 3 must not b\
e zero")
                    except AttributeError :
                        raise StopIteration
                    res = self.__a
                    self.__a += self.__step
                    return res
                else :
                    self.__a = self.__start
                    self.next()
                    return self.__start
        
        def __repr__(self) :
            """x.__repr__() <==> repr(x)"""
            
            if self.step == 1 :
                return "ProtectedRange(%s, %s)" % (repr(self.start),
                                                   repr(self.stop))
            return "ProtectedRange(%s, %s, %s)" % (repr(self.start),
                                                   repr(self.stop),
                                                   repr(self.step))
        
        def __iter__(self) :
            """x.__iter__() <==> iter(x)"""
            
            try :
                self.start + self.start - self.start # protect
            except (TypeError, ValueError, MemoryError) :
                raise ValueError("protected range")
            return type(self).ProtectedRange_iterator(self.start, self.stop,
                                                      self.step)
        
        def __getitem__(self, key) :
            """x.__getitem__(y) <==> x[y]"""
            
            try :
                if isinstance(key, slice) :
                    if key.step != None :
                        if key.step + key.step == key.step :
                            raise ValueError("slice step cannot be zero")
                    k = (key.step, 1)[key.step==None]
                    labb = tuple(self)[key]
                    return type(self)(labb[0],labb[-1]+self.step*k, self.step*k)
            except NameError :
                pass
            try :
                return tuple(self)[key]
            except IndexError :
                raise IndexError("ProtectedRange object index out of range")
    
    def index(self, value) :
        try :
            return tuple(self).index(value)
        except ValueError :
            raise ValueError("%s is not in ProtectedRange"%repr(value))

del ispy3



#!/usr/bin/env python
# coding=UTF-8
# Author: cheny0y0<https://github.com/cheny0y0><cyy144881@icloud.com>, REGE<https://github.com/IAmREGE>

import sys
try :
    from setuptools import setup
    import setuptools
except ImportError :
    raise ImportError("setuptools not found! please run 'pip install setuptools'.")

fh = open("README.md", "r", encoding="utf-8")
long_description = fh.read()
fh.close()

setup(
    name="range-anytype",
    version="0.6.10.923143b",
    description="Range object for any type for Python.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="cheny0y0, REGE",
    author_email="cyy144881@icloud.com",
    url="",
    packages=setuptools.find_packages(),
    
    install_requires=[],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Operating System :: Android",
        "Operating System :: MacOS",
        "Operating System :: Microsoft",
        "Operating System :: Other OS",
        "Operating System :: POSIX",
        "Operating System :: Unix",
        "Operating System :: iOS",
        "Programming Language :: Python",
#        "Programming Language :: Python :: 1",
#        "Programming Language :: Python :: 1.0",
#        "Programming Language :: Python :: 1.1",
#        "Programming Language :: Python :: 1.2",
#        "Programming Language :: Python :: 1.3",
#        "Programming Language :: Python :: 1.4",
#        "Programming Language :: Python :: 1.5",
#        "Programming Language :: Python :: 1.6",
        "Programming Language :: Python :: 2",
#        "Programming Language :: Python :: 2.0",
#        "Programming Language :: Python :: 2.1",
#        "Programming Language :: Python :: 2.2",
        "Programming Language :: Python :: 2.3",
        "Programming Language :: Python :: 2.4",
        "Programming Language :: Python :: 2.5",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Software Development :: Libraries"
    ],
    zip_safe=True,
)
